@@ -507,6 +507,13 @@ AppUi::AppUi(lua_State *L0, int model, Qt::WFlags f)
   iResolution = new QLabel(statusBar());
   statusBar()->addPermanentWidget(iResolution, 0);
 
+  lua_getglobal(L, "prefs");
+  lua_getfield(L, -1, "retina");
+  int retina = lua_toboolean(L, -1) ? 2 : 1;
+  ipeDebug("setRetina(%d)", retina);
+  iCanvas->setRetina(retina);
+  lua_pop(L, 2); // retina, prefs
+
   iCanvas->setObserver(this);
 }
 
@@ -811,7 +818,7 @@ static const char * const aboutText =
 "<li> Some code from Xpdf"
 "</ul>"
 "<p>Ipe is released under the GNU Public License.</p>"
-"<p>See <a href=\"http://ipe7.sourceforge.net\">ipe7.sourceforge.net</a>"
+"<p>See <a href=\"http://ipe.otfried.org\">ipe.otfried.org</a>"
 " for details.</p>"
 "</qt>";
 
