@@ -1095,7 +1095,7 @@ static const char * const aboutText =
   " * The compression library zlib %s\n"
   " * Some code from Xpdf\n\n"
   "Ipe is released under the GNU Public License.\n"
-  "See ipe7.sourceforge.net for details.";
+  "See http://ipe.otfried.org for details.";
 
 void AppUi::aboutIpe()
 {
