@@ -311,7 +311,11 @@ function MODEL:showLayerBoxPopup(v, layer)
   local p = self:page()
   local m = ipeui.Menu(self.ui:win())
   local active = p:active(self.vno)
-  m:add("checkfrom", "Check " .. layer .. " from view " .. self.vno)
+  if p:visible(self.vno, layer) then
+    m:add("invisible", "Make " .. layer .. " invisible in view " .. self.vno)
+  else
+    m:add("visible", "Make " .. layer .. " visible in view " .. self.vno)
+  end
   m:add("rename", "Rename " .. layer)
   m:add("delete", "Delete " .. layer)
   if layer ~= active then
@@ -349,9 +353,15 @@ end
 
 ----------------------------------------------------------------------
 
-function MODEL:layeraction_checkfrom(layer, arg)
+function MODEL:layeraction_make_visible(layer, arg, vis)
   local p = self:page()
-  local t = { label="make layer " .. layer .. " visible from view " .. self.vno,
+  local label
+  if vis then
+    label = "make layer " .. layer .. " visible in view " .. self.vno
+  else
+    label = "make layer " .. layer .. " invisible in view " .. self.vno
+  end
+  local t = { label=label,
 	      pno=self.pno,
 	      vno=self.vno,
 	      original=p:clone(),
@@ -360,12 +370,20 @@ function MODEL:layeraction_checkfrom(layer, arg)
 	    }
   t.redo = function (t, doc)
 	     for j = t.vno, doc[t.pno]:countViews() do
-	       doc[t.pno]:setVisible(j, t.layer, true)
+	       doc[t.pno]:setVisible(j, t.layer, vis)
 	     end
 	   end
   self:register(t)
 end
 
+function MODEL:layeraction_visible(layer, arg)
+  self:layeraction_make_visible(layer, arg, true)
+end
+
+function MODEL:layeraction_invisible(layer, arg)
+  self:layeraction_make_visible(layer, arg, false)
+end
+
 function MODEL:layeraction_select(layer, arg)
   local p = self:page()
   local t = { label="set visibility of layer " .. layer,
@@ -736,11 +754,13 @@ function MODEL:action_show_configuration()
   s = s .. "\n * Styles for new documents: " ..
     table.concat(prefs.styles, ", ")
   s = s .. "\n * Autosave file: " .. prefs.autosave_filename
+  s = s .. "\n * Save-as directory: " .. prefs.save_as_directory
   s = s .. "\n * Documentation: " .. config.docdir
   s = s .. "\n * Ipelets:\n   - " .. table.concat(config.ipeletDirs, "\n   - ")
   s = s .. "\n * Latex directory: " .. config.latexdir
   s = s .. "\n * Fontmap: " .. config.fontmap
   s = s .. "\n * Icons: " .. config.icons
+  s = s .. "\n * External editor: " .. (prefs.external_editor or "none")
   messageBox(self.ui:win(), "information", "Ipe configuration", s)
 end
 
@@ -1043,7 +1063,7 @@ end
 
 function MODEL:action_normal_size()
   local p = self:page()
-  self.ui:setZoom(1)
+  self.ui:setZoom(prefs.normal_resolution / 72.0)
   local layout = self.doc:sheets():find("layout")
   local paper = ipe.Rect()
   paper:add(-layout.origin)
