@@ -711,7 +711,7 @@ function MODEL:createText(mode)
   end
   local d = ipeui.Dialog(self.ui:win(), "Create text object")
   d:add("label", "label", { label=prompt }, 1, 1, 1, 2)
-  d:add("text", "text", { syntax="latex", focus=true }, 2, 1)
+  d:add("text", "text", { syntax="latex", focus=true }, 2, 1, 1, 2)
   addEditorField(d, "text")
   d:addButton("ok", "&Ok", "accept")
   d:addButton("cancel", "&Cancel", "reject")
@@ -958,7 +958,7 @@ local mouse_mappings = {
 }
 
 function MODEL:mouseButtonAction(button, modifiers)
-  print("Mouse button", button, modifiers.alt, modifiers.control)
+  -- print("Mouse button", button, modifiers.alt, modifiers.control)
   if button == 1 and not modifiers.alt and
     not modifiers.control and not modifiers.meta then
     self:startModeTool(modifiers)
