@@ -32,9 +32,17 @@
 #include "ipeutils.h"
 #include <zlib.h>
 
-#include <turbojpeg.h>
+#include <cstdio>
+
 #include <png.h>
 
+#if defined(WIN32) || defined(IPE_TURBOJPEG_API)
+#include <turbojpeg.h>
+#else
+#include <csetjmp>
+#include <jpeglib.h>
+#endif
+
 using namespace ipe;
 
 // --------------------------------------------------------------------
@@ -332,6 +340,7 @@ void Bitmap::computeChecksum()
 
 // --------------------------------------------------------------------
 
+#if defined(WIN32) || defined(IPE_TURBOJPEG_API)
 bool dctDecode(Buffer dctData, Buffer pixelData, int components)
 {
   tjhandle handle = tjInitDecompress();
@@ -365,6 +374,58 @@ bool dctDecode(Buffer dctData, Buffer pixelData, int components)
   return true;
 }
 
+#else
+// Decode jpeg image using libjpeg API with error handling
+// Code contributed by Michael Thon, 2015.
+
+// The following is error-handling code for decompressing jpeg using the
+// standard libjpeg API. Taken from the example.c and stackoverflow.
+struct jpegErrorManager {
+  struct jpeg_error_mgr pub;
+  jmp_buf setjmp_buffer;
+};
+
+static char jpegLastErrorMsg[JMSG_LENGTH_MAX];
+
+static void jpegErrorExit (j_common_ptr cinfo)
+{
+  jpegErrorManager *myerr = (jpegErrorManager*) cinfo->err;
+  (*(cinfo->err->format_message)) (cinfo, jpegLastErrorMsg);
+  longjmp(myerr->setjmp_buffer, 1);
+}
+
+bool dctDecode(Buffer dctData, Buffer pixelData, int components)
+{
+  struct jpeg_decompress_struct cinfo;
+
+  // Error handling:
+  struct jpegErrorManager jerr;
+  cinfo.err = jpeg_std_error(&jerr.pub);
+  jerr.pub.error_exit = jpegErrorExit;
+  if (setjmp(jerr.setjmp_buffer)) {
+    ipeDebug("jpeg decompression failed: %s", jpegLastErrorMsg);
+    jpeg_destroy_decompress(&cinfo);
+    return false;
+  }
+  // Decompression:
+  jpeg_create_decompress(&cinfo);
+  jpeg_mem_src(&cinfo, (unsigned char *) dctData.data(), dctData.size());
+  jpeg_read_header(&cinfo, 1);
+  cinfo.out_color_space = ((components == 3) ? JCS_RGB : JCS_GRAYSCALE);
+  jpeg_start_decompress(&cinfo);
+  while (cinfo.output_scanline < cinfo.output_height) {
+    int row_stride = cinfo.output_width * cinfo.output_components;
+    int index = cinfo.output_scanline * row_stride;
+    unsigned char *buffer[1];
+    buffer[0] = (unsigned char *) &(pixelData[index]);
+    jpeg_read_scanlines(&cinfo, buffer, 1);
+  }
+  jpeg_finish_decompress(&cinfo);
+  jpeg_destroy_decompress(&cinfo);
+  return true;
+}
+#endif
+
 //! Convert bitmap data to a height x width pixel array in rgb format.
 /*! Returns empty buffer if it cannot decode the bitmap information.
   Otherwise, returns a buffer of size width() * height() uint's. */
