@@ -251,6 +251,8 @@ void Dialog::addLabel(lua_State *L, SElement &m)
     }
     ++curlen;
   }
+  if (curlen > maxlen)
+    maxlen = curlen;
   m.minWidth = 4 * maxlen;
 }
 
