@@ -618,6 +618,11 @@ void PDialog::computeDimensions(int &w, int &h)
       iRowHeight[i] = minHeight[i] + extra;
     }
   }
+  fprintf(stderr, "iColWidth\n");
+  for (int i = 0; i < iNoCols; ++i)
+    fprintf(stderr, "%d ", iColWidth[i]);
+  fprintf(stderr, "\n");
+  fflush(stderr);
 }
 
 void PDialog::enableItem(int idx, bool value)
